@@ -16,6 +16,7 @@
 
 import sys
 import os
+from calculate.lib.utils.tools import unpack_single_opts
 import cert_cmd
 import pwd
 from calculate.core.server.func import clearDataVars
@@ -32,20 +33,20 @@ _('No module named %s')
 
 @clearDataVars
 def main(*args, **keywords):
+    _args = list(unpack_single_opts(sys.argv[1:]))
     if os.path.basename(sys.argv[0]) != 'cl-core':
         parser = cert_cmd.parse(full=False)
-        args, unknown_args = parser.parse_known_args()
+        args, unknown_args = parser.parse_known_args(_args)
         args.method = '_temp_'
     else:
         parser = cert_cmd.parse(full=True)
-        args, unknown_args = parser.parse_known_args()
+        args, unknown_args = parser.parse_known_args(_args)
         if args.method:
             parser = cert_cmd.parse(full=False)
-            args, unknown_args = parser.parse_known_args()
-
+            args, unknown_args = parser.parse_known_args(_args)
     if not args.method:
         if unknown_args:
-            args = parser.parse_args()
+            args = parser.parse_args(_args)
 
     if args.help and not args.method:
         parser.print_help()
